@@ -1,28 +1,18 @@
-// Copyright 2018 the Kurbo Authors
-// SPDX-License-Identifier: Apache-2.0 OR MIT
-
 //! Cubic Bézier segments.
 
-use alloc::vec;
-use alloc::vec::Vec;
-use core::ops::{Mul, Range};
+use std::ops::{Mul, Range};
 
 use crate::MAX_EXTREMA;
 use crate::{Line, QuadSpline, Vec2};
 use arrayvec::ArrayVec;
 
-use crate::common::{
-    solve_quadratic, GAUSS_LEGENDRE_COEFFS_16_HALF, GAUSS_LEGENDRE_COEFFS_24_HALF,
-    GAUSS_LEGENDRE_COEFFS_8, GAUSS_LEGENDRE_COEFFS_8_HALF,
-};
+use crate::common::solve_quadratic;
+use crate::common::GAUSS_LEGENDRE_COEFFS_9;
 use crate::{
     Affine, Nearest, ParamCurve, ParamCurveArclen, ParamCurveArea, ParamCurveCurvature,
     ParamCurveDeriv, ParamCurveExtrema, ParamCurveNearest, PathEl, Point, QuadBez, Rect, Shape,
 };
 
-#[cfg(not(feature = "std"))]
-use crate::common::FloatFuncs;
-
 const MAX_SPLINE_SPLIT: usize = 100;
 
 /// A single cubic Bézier segment.
@@ -225,7 +215,7 @@ impl CubicBez {
         let delta_2 = dt * dt;
         let delta_3 = dt * delta_2;
 
-        core::iter::from_fn(move || {
+        std::iter::from_fn(move || {
             // if storage exists, we use it exclusively
             if let Some(storage) = storage.as_mut() {
                 return storage.pop();
@@ -256,13 +246,13 @@ impl CubicBez {
         (a, b, c, d)
     }
 
-    /// Rust port of cu2qu [calc_cubic_points](https://github.com/fonttools/fonttools/blob/3b9a73ff8379ab49d3ce35aaaaf04b3a7d9d1655/Lib/fontTools/cu2qu/cu2qu.py#L63-L68)
     fn from_parameters(a: Vec2, b: Vec2, c: Vec2, d: Vec2) -> Self {
-        let p0 = d.to_point();
-        let p1 = c.div_exact(3.0).to_point() + d;
-        let p2 = (b + c).div_exact(3.0).to_point() + p1.to_vec2();
-        let p3 = (a + d + c + b).to_point();
-        CubicBez::new(p0, p1, p2, p3)
+        CubicBez::new(
+            d.to_point(),
+            d.to_point() + (c / 3.0),
+            d.to_point() + (c / 3.0) + (b + c) / 3.0,
+            d.to_point() + (c / 3.0) + (b + c) / 3.0 + a,
+        )
     }
 
     fn subdivide_3(&self) -> (CubicBez, CubicBez, CubicBez) {
@@ -272,22 +262,13 @@ impl CubicBez {
             self.p2.to_vec2(),
             self.p3.to_vec2(),
         );
-        // The original Python cu2qu code here does not use division operator to divide by 27 but
-        // instead uses multiplication by the reciprocal 1 / 27. We want to match it exactly
-        // to avoid any floating point differences, hence in this particular case we do not use div_exact.
-        // I could directly use the Vec2 Div trait (also implemented as multiplication by reciprocal)
-        // but I prefer to be explicit here.
-        // Source: https://github.com/fonttools/fonttools/blob/85c80be/Lib/fontTools/cu2qu/cu2qu.py#L215-L218
-        // See also: https://github.com/linebender/kurbo/issues/272
-        let one_27th = 27.0_f64.recip();
-        let mid1 = ((8.0 * p0 + 12.0 * p1 + 6.0 * p2 + p3) * one_27th).to_point();
-        let deriv1 = (p3 + 3.0 * p2 - 4.0 * p0) * one_27th;
-        let mid2 = ((p0 + 6.0 * p1 + 12.0 * p2 + 8.0 * p3) * one_27th).to_point();
-        let deriv2 = (4.0 * p3 - 3.0 * p1 - p0) * one_27th;
-
+        let mid1 = ((8.0 * p0 + 12.0 * p1 + 6.0 * p2 + p3) / 27.0).to_point();
+        let deriv1 = (p3 + 3.0 * p2 - 4.0 * p0) / 27.0;
+        let mid2 = ((p0 + 6.0 * p1 + 12.0 * p2 + 8.0 * p3) / 27.0).to_point();
+        let deriv2 = (4.0 * p3 - 3.0 * p1 - p0) / 27.0;
         let left = CubicBez::new(
             self.p0,
-            (2.0 * p0 + p1).div_exact(3.0).to_point(),
+            ((2.0 * p0 + p1) / 3.0).to_point(),
             mid1 - deriv1,
             mid1,
         );
@@ -295,15 +276,13 @@ impl CubicBez {
         let right = CubicBez::new(
             mid2,
             mid2 + deriv2,
-            (p2 + 2.0 * p3).div_exact(3.0).to_point(),
+            ((p2 + 2.0 * p3) / 3.0).to_point(),
             self.p3,
         );
         (left, mid, right)
     }
 
     /// Does this curve fit inside the given distance from the origin?
-    ///
-    /// Rust port of cu2qu [cubic_farthest_fit_inside](https://github.com/fonttools/fonttools/blob/3b9a73ff8379ab49d3ce35aaaaf04b3a7d9d1655/Lib/fontTools/cu2qu/cu2qu.py#L281)
     fn fit_inside(&self, distance: f64) -> bool {
         if self.p2.to_vec2().hypot() <= distance && self.p1.to_vec2().hypot() <= distance {
             return true;
@@ -330,24 +309,6 @@ impl CubicBez {
     pub fn is_nan(&self) -> bool {
         self.p0.is_nan() || self.p1.is_nan() || self.p2.is_nan() || self.p3.is_nan()
     }
-
-    /// Determine the inflection points.
-    ///
-    /// Return value is t parameter for the inflection points of the curve segment.
-    /// There are a maximum of two for a cubic Bézier.
-    ///
-    /// See <https://www.caffeineowl.com/graphics/2d/vectorial/cubic-inflexion.html>
-    /// for the theory.
-    pub fn inflections(&self) -> ArrayVec<f64, 2> {
-        let a = self.p1 - self.p0;
-        let b = (self.p2 - self.p1) - a;
-        let c = (self.p3 - self.p0) - 3. * (self.p2 - self.p1);
-        solve_quadratic(a.cross(b), a.cross(c), b.cross(c))
-            .iter()
-            .copied()
-            .filter(|t| *t >= 0.0 && *t <= 1.0)
-            .collect()
-    }
 }
 
 /// An iterator for cubic beziers.
@@ -357,7 +318,7 @@ pub struct CubicBezIter {
 }
 
 impl Shape for CubicBez {
-    type PathElementsIter<'iter> = CubicBezIter;
+    type PathElementsIter = CubicBezIter;
 
     #[inline]
     fn path_elements(&self, _tolerance: f64) -> CubicBezIter {
@@ -467,65 +428,46 @@ impl ParamCurveDeriv for CubicBez {
     }
 }
 
-fn arclen_quadrature_core(coeffs: &[(f64, f64)], dm: Vec2, dm1: Vec2, dm2: Vec2) -> f64 {
-    coeffs
-        .iter()
-        .map(|&(wi, xi)| {
-            let d = dm + dm2 * (xi * xi);
-            let dpx = (d + dm1 * xi).hypot();
-            let dmx = (d - dm1 * xi).hypot();
-            (2.25f64.sqrt() * wi) * (dpx + dmx)
-        })
-        .sum::<f64>()
-}
-
-fn arclen_rec(c: &CubicBez, accuracy: f64, depth: usize) -> f64 {
-    let d03 = c.p3 - c.p0;
-    let d01 = c.p1 - c.p0;
-    let d12 = c.p2 - c.p1;
-    let d23 = c.p3 - c.p2;
-    let lp_lc = d01.hypot() + d12.hypot() + d23.hypot() - d03.hypot();
-    let dd1 = d12 - d01;
-    let dd2 = d23 - d12;
-    // It might be faster to do direct multiplies, the data dependencies would be shorter.
-    // The following values don't have the factor of 3 for first deriv
-    let dm = 0.25 * (d01 + d23) + 0.5 * d12; // first derivative at midpoint
-    let dm1 = 0.5 * (dd2 + dd1); // second derivative at midpoint
-    let dm2 = 0.25 * (dd2 - dd1); // 0.5 * (third derivative at midpoint)
-
-    let est = GAUSS_LEGENDRE_COEFFS_8
-        .iter()
-        .map(|&(wi, xi)| {
-            wi * {
-                let d_norm2 = (dm + dm1 * xi + dm2 * (xi * xi)).hypot2();
-                let dd_norm2 = (dm1 + dm2 * (2.0 * xi)).hypot2();
-                dd_norm2 / d_norm2
-            }
-        })
-        .sum::<f64>();
-    let est_gauss8_error = (est.powi(3) * 2.5e-6).min(3e-2) * lp_lc;
-    if est_gauss8_error < accuracy {
-        return arclen_quadrature_core(GAUSS_LEGENDRE_COEFFS_8_HALF, dm, dm1, dm2);
-    }
-    let est_gauss16_error = (est.powi(6) * 1.5e-11).min(9e-3) * lp_lc;
-    if est_gauss16_error < accuracy {
-        return arclen_quadrature_core(GAUSS_LEGENDRE_COEFFS_16_HALF, dm, dm1, dm2);
-    }
-    let est_gauss24_error = (est.powi(9) * 3.5e-16).min(3.5e-3) * lp_lc;
-    if est_gauss24_error < accuracy || depth >= 20 {
-        return arclen_quadrature_core(GAUSS_LEGENDRE_COEFFS_24_HALF, dm, dm1, dm2);
-    }
-    let (c0, c1) = c.subdivide();
-    arclen_rec(&c0, accuracy * 0.5, depth + 1) + arclen_rec(&c1, accuracy * 0.5, depth + 1)
-}
-
 impl ParamCurveArclen for CubicBez {
     /// Arclength of a cubic Bézier segment.
     ///
     /// This is an adaptive subdivision approach using Legendre-Gauss quadrature
     /// in the base case, and an error estimate to decide when to subdivide.
     fn arclen(&self, accuracy: f64) -> f64 {
-        arclen_rec(self, accuracy, 0)
+        // Squared L2 norm of the second derivative of the cubic.
+        fn cubic_errnorm(c: &CubicBez) -> f64 {
+            let d = c.deriv().deriv();
+            let dd = d.end() - d.start();
+            d.start().to_vec2().hypot2() + d.start().to_vec2().dot(dd) + dd.hypot2() * (1.0 / 3.0)
+        }
+        fn est_gauss9_error(c: &CubicBez) -> f64 {
+            let lc2 = (c.p3 - c.p0).hypot2();
+            let lp = (c.p1 - c.p0).hypot() + (c.p2 - c.p1).hypot() + (c.p3 - c.p2).hypot();
+
+            2.56e-8 * (cubic_errnorm(c) / lc2).powi(8) * lp
+        }
+        const MAX_DEPTH: usize = 16;
+        fn rec(c: &CubicBez, accuracy: f64, depth: usize) -> f64 {
+            if depth == MAX_DEPTH || est_gauss9_error(c) < accuracy {
+                c.gauss_arclen(GAUSS_LEGENDRE_COEFFS_9)
+            } else {
+                let (c0, c1) = c.subdivide();
+                rec(&c0, accuracy * 0.5, depth + 1) + rec(&c1, accuracy * 0.5, depth + 1)
+            }
+        }
+
+        // Check if the bezier curve is degenerate, or almost degenerate
+        // A degenerate curve where all points are identical will cause infinite recursion in the rec function (well, until MAX_DEPTH at least) in all branches.
+        // This test will in addition be true if the bezier curve is just a simple line (i.e. p0=p1 and p2=p3).
+        // The constant 0.5 has not been mathematically proven to be small enough, but from empirical tests
+        // a value of about 0.87 should be enough. Thus 0.5 is a conservative value.
+        // See https://github.com/linebender/kurbo/pull/100 for more info.
+        if (self.p1 - self.p0).hypot2() + (self.p2 - self.p3).hypot2() <= 0.5 * accuracy * accuracy
+        {
+            (self.p0 - self.p3).hypot()
+        } else {
+            rec(self, accuracy, 0)
+        }
     }
 }
 
@@ -629,8 +571,6 @@ impl Iterator for ToQuads {
 /// Convert multiple cubic Bézier curves to quadratic splines.
 ///
 /// Ensures that the resulting splines have the same number of control points.
-///
-/// Rust port of cu2qu [cubic_approx_quadratic](https://github.com/fonttools/fonttools/blob/3b9a73ff8379ab49d3ce35aaaaf04b3a7d9d1655/Lib/fontTools/cu2qu/cu2qu.py#L322)
 pub fn cubics_to_quadratic_splines(curves: &[CubicBez], accuracy: f64) -> Option<Vec<QuadSpline>> {
     let mut result = Vec::new();
     let mut split_order = 0;
@@ -657,7 +597,6 @@ mod tests {
     use crate::{
         cubics_to_quadratic_splines, Affine, CubicBez, Nearest, ParamCurve, ParamCurveArclen,
         ParamCurveArea, ParamCurveDeriv, ParamCurveExtrema, ParamCurveNearest, Point, QuadBez,
-        QuadSpline,
     };
 
     #[test]
@@ -719,7 +658,10 @@ mod tests {
                 let actual_arc = c.subsegment(0.0..t).arclen(accuracy * 0.5);
                 assert!(
                     (arc - actual_arc).abs() < accuracy,
-                    "at accuracy {accuracy:e}, wanted {actual_arc} got {arc}"
+                    "at accuracy {:e}, wanted {} got {}",
+                    accuracy,
+                    actual_arc,
+                    arc
                 );
             }
         }
@@ -730,7 +672,10 @@ mod tests {
         let actual_arc = c.subsegment(0.0..t).arclen(accuracy);
         assert!(
             (arc - actual_arc).abs() < 2.0 * accuracy,
-            "at accuracy {accuracy:e}, want {actual_arc} got {arc}"
+            "at accuracy {:e}, want {} got {}",
+            accuracy,
+            actual_arc,
+            arc
         );
     }
 
@@ -778,7 +723,9 @@ mod tests {
         fn verify(result: Nearest, expected: f64) {
             assert!(
                 (result.t - expected).abs() < 1e-6,
-                "got {result:?} expected {expected}"
+                "got {:?} expected {}",
+                result,
+                expected
             );
         }
         // y = x^3
@@ -837,7 +784,7 @@ mod tests {
                     let p = q.eval(t);
                     let err = (p.y - p.x.powi(3)).abs();
                     worst = worst.max(err);
-                    assert!(err < accuracy, "got {err} wanted {accuracy}");
+                    assert!(err < accuracy, "got {} wanted {}", err, accuracy);
                 }
             }
         }
@@ -930,104 +877,4 @@ mod tests {
             converted[0].points()[2].distance(Point::new(88639.0 / 90.0, 52584.0 / 90.0)) < 0.0001
         );
     }
-
-    #[test]
-    fn cubicbez_approx_spline_div_exact() {
-        // Ensure rounding behavior for division matches fonttools
-        // cu2qu.
-        // See <https://github.com/linebender/kurbo/issues/272>
-        let cubic = CubicBez::new(
-            Point::new(408.0, 321.0),
-            Point::new(408.0, 452.0),
-            Point::new(342.0, 560.0),
-            Point::new(260.0, 560.0),
-        );
-        let spline = cubic.approx_spline(1.0).unwrap();
-        assert_eq!(
-            spline.points(),
-            &[
-                Point::new(408.0, 321.0),
-                // Previous behavior produced 386.49999999999994 for the
-                // y coordinate leading to inconsistent rounding.
-                Point::new(408.0, 386.5),
-                Point::new(368.16666666666663, 495.0833333333333),
-                Point::new(301.0, 560.0),
-                Point::new(260.0, 560.0)
-            ]
-        )
-    }
-
-    #[test]
-    fn cubicbez_inflections() {
-        let c = CubicBez::new((0., 0.), (0.8, 1.), (0.2, 1.), (1., 0.));
-        let inflections = c.inflections();
-        assert_eq!(inflections.len(), 2);
-        assert!((inflections[0] - 0.311018).abs() < 1e-6);
-        assert!((inflections[1] - 0.688982).abs() < 1e-6);
-        let c = CubicBez::new((0., 0.), (1., 1.), (2., -1.), (3., 0.));
-        let inflections = c.inflections();
-        assert_eq!(inflections.len(), 1);
-        assert!((inflections[0] - 0.5).abs() < 1e-6);
-        let c = CubicBez::new((0., 0.), (1., 1.), (2., 1.), (3., 0.));
-        let inflections = c.inflections();
-        assert_eq!(inflections.len(), 0);
-    }
-
-    #[test]
-    fn cubic_to_quadratic_matches_python() {
-        // from https://github.com/googlefonts/fontmake-rs/issues/217
-        let cubic = CubicBez {
-            p0: (796.0, 319.0).into(),
-            p1: (727.0, 314.0).into(),
-            p2: (242.0, 303.0).into(),
-            p3: (106.0, 303.0).into(),
-        };
-
-        // FontTools can approximate this curve successfully in 7 splits, we can too
-        assert!(cubic.approx_spline_n(7, 1.0).is_some());
-
-        // FontTools can solve this with accuracy 0.001, we can too
-        assert!(cubics_to_quadratic_splines(&[cubic], 0.001).is_some());
-    }
-
-    #[test]
-    fn cubics_to_quadratic_splines_matches_python() {
-        // https://github.com/linebender/kurbo/pull/273
-        let light = CubicBez::new((378., 608.), (378., 524.), (355., 455.), (266., 455.));
-        let regular = CubicBez::new((367., 607.), (367., 511.), (338., 472.), (243., 472.));
-        let bold = CubicBez::new(
-            (372.425, 593.05),
-            (372.425, 524.95),
-            (355.05, 485.95),
-            (274., 485.95),
-        );
-        let qsplines = cubics_to_quadratic_splines(&[light, regular, bold], 1.0).unwrap();
-        assert_eq!(
-            qsplines,
-            [
-                QuadSpline::new(vec![
-                    (378.0, 608.0).into(),
-                    (378.0, 566.0).into(),
-                    (359.0833333333333, 496.5).into(),
-                    (310.5, 455.0).into(),
-                    (266.0, 455.0).into(),
-                ]),
-                QuadSpline::new(vec![
-                    (367.0, 607.0).into(),
-                    (367.0, 559.0).into(),
-                    // Previous behavior produced 496.5 for the y coordinate
-                    (344.5833333333333, 499.49999999999994).into(),
-                    (290.5, 472.0).into(),
-                    (243.0, 472.0).into(),
-                ]),
-                QuadSpline::new(vec![
-                    (372.425, 593.05).into(),
-                    (372.425, 559.0).into(),
-                    (356.98333333333335, 511.125).into(),
-                    (314.525, 485.95).into(),
-                    (274.0, 485.95).into(),
-                ]),
-            ]
-        )
-    }
 }
