@@ -5,6 +5,7 @@
     target_has_atomic = "64",
 ))]
 mod atomic;
+mod niching;
 
 use core::{
     cell::{Cell, UnsafeCell},
@@ -19,28 +20,41 @@ use core::{
 };
 
 use munge::munge;
-use rancor::Fallible;
+use rancor::{Fallible, Source};
 
 use crate::{
     boxed::{ArchivedBox, BoxResolver},
-    niche::option_nonzero::{
-        ArchivedOptionNonZeroI128, ArchivedOptionNonZeroI16,
-        ArchivedOptionNonZeroI32, ArchivedOptionNonZeroI64,
-        ArchivedOptionNonZeroI8, ArchivedOptionNonZeroIsize,
-        ArchivedOptionNonZeroU128, ArchivedOptionNonZeroU16,
-        ArchivedOptionNonZeroU32, ArchivedOptionNonZeroU64,
-        ArchivedOptionNonZeroU8, ArchivedOptionNonZeroUsize,
+    niche::{
+        niched_option::NichedOption,
+        niching::{DefaultNiche, Niching},
+        option_nonzero::{
+            ArchivedOptionNonZeroI128, ArchivedOptionNonZeroI16,
+            ArchivedOptionNonZeroI32, ArchivedOptionNonZeroI64,
+            ArchivedOptionNonZeroI8, ArchivedOptionNonZeroIsize,
+            ArchivedOptionNonZeroU128, ArchivedOptionNonZeroU16,
+            ArchivedOptionNonZeroU32, ArchivedOptionNonZeroU64,
+            ArchivedOptionNonZeroU8, ArchivedOptionNonZeroUsize,
+        },
     },
     option::ArchivedOption,
     primitive::{FixedNonZeroIsize, FixedNonZeroUsize},
+    ser::{Allocator, Writer},
+    string::{ArchivedString, StringResolver},
     traits::NoUndef,
+    vec::{ArchivedVec, VecResolver},
     with::{
-        ArchiveWith, AsBox, DeserializeWith, Identity, Inline, InlineAsBox,
-        Map, Niche, SerializeWith, Skip, Unsafe,
+        ArchiveWith, AsBox, AsString, AsVec, DeserializeWith, Identity, Inline,
+        InlineAsBox, Map, MapNiche, Niche, NicheInto, SerializeWith, Skip,
+        Unsafe,
     },
     Archive, ArchiveUnsized, Deserialize, Place, Serialize, SerializeUnsized,
 };
 
+// This is used by various internal impls, but isn't something we want to make a
+// public API. However, in some build configurations there end up being no uses
+// of this helper at all. So the most straightforward way to solve this is to
+// just allow this code to be unused.
+#[allow(dead_code)]
 // Wrapper for O so that we have an Archive and Serialize implementation
 // and ArchivedVec::serialize_from_* is happy about the bound
 // constraints
@@ -107,6 +121,63 @@ where
     }
 }
 
+// AsString
+
+impl ArchiveWith<&str> for AsString {
+    type Archived = ArchivedString;
+    type Resolver = StringResolver;
+
+    fn resolve_with(
+        field: &&str,
+        resolver: Self::Resolver,
+        out: Place<Self::Archived>,
+    ) {
+        ArchivedString::resolve_from_str(field, resolver, out);
+    }
+}
+
+impl<S> SerializeWith<&str, S> for AsString
+where
+    str: SerializeUnsized<S>,
+    S: Fallible + ?Sized,
+    S::Error: Source,
+{
+    fn serialize_with(
+        field: &&str,
+        serializer: &mut S,
+    ) -> Result<Self::Resolver, S::Error> {
+        ArchivedString::serialize_from_str(field, serializer)
+    }
+}
+
+// AsVec
+
+impl<T: Archive> ArchiveWith<&[T]> for AsVec {
+    type Archived = ArchivedVec<T::Archived>;
+    type Resolver = VecResolver;
+
+    fn resolve_with(
+        field: &&[T],
+        resolver: Self::Resolver,
+        out: Place<Self::Archived>,
+    ) {
+        ArchivedVec::resolve_from_len(field.len(), resolver, out);
+    }
+}
+
+impl<T, S> SerializeWith<&[T], S> for AsVec
+where
+    T: Serialize<S>,
+    S: Fallible + Allocator + Writer + ?Sized,
+{
+    fn serialize_with(
+        field: &&[T],
+        serializer: &mut S,
+    ) -> Result<Self::Resolver, S::Error> {
+        ArchivedVec::serialize_from_slice(field, serializer)
+    }
+}
+
 // AsBox
 
 impl<F: ArchiveUnsized + ?Sized> ArchiveWith<F> for AsBox {
@@ -385,6 +456,188 @@ where
     }
 }
 
+// NicheInto
+
+impl<T, N> ArchiveWith<Option<T>> for NicheInto<N>
+where
+    T: Archive,
+    N: Niching<T::Archived> + ?Sized,
+{
+    type Archived = NichedOption<T::Archived, N>;
+    type Resolver = Option<T::Resolver>;
+
+    fn resolve_with(
+        field: &Option<T>,
+        resolver: Self::Resolver,
+        out: Place<Self::Archived>,
+    ) {
+        NichedOption::<T::Archived, N>::resolve_from_option(
+            field.as_ref(),
+            resolver,
+            out,
+        );
+    }
+}
+
+impl<T, N, S> SerializeWith<Option<T>, S> for NicheInto<N>
+where
+    T: Serialize<S>,
+    N: Niching<T::Archived> + ?Sized,
+    S: Fallible + ?Sized,
+{
+    fn serialize_with(
+        field: &Option<T>,
+        serializer: &mut S,
+    ) -> Result<Self::Resolver, S::Error> {
+        NichedOption::<T::Archived, N>::serialize_from_option(
+            field.as_ref(),
+            serializer,
+        )
+    }
+}
+
+impl<T, N, D> DeserializeWith<NichedOption<T::Archived, N>, Option<T>, D>
+    for NicheInto<N>
+where
+    T: Archive<Archived: Deserialize<T, D>>,
+    N: Niching<T::Archived> + ?Sized,
+    D: Fallible + ?Sized,
+{
+    fn deserialize_with(
+        field: &NichedOption<T::Archived, N>,
+        deserializer: &mut D,
+    ) -> Result<Option<T>, D::Error> {
+        Deserialize::deserialize(field, deserializer)
+    }
+}
+
+impl<T, N, D> Deserialize<Option<T>, D> for NichedOption<T::Archived, N>
+where
+    T: Archive<Archived: Deserialize<T, D>>,
+    N: Niching<T::Archived> + ?Sized,
+    D: Fallible + ?Sized,
+{
+    fn deserialize(&self, deserializer: &mut D) -> Result<Option<T>, D::Error> {
+        match self.as_ref() {
+            Some(value) => value.deserialize(deserializer).map(Some),
+            None => Ok(None),
+        }
+    }
+}
+
+// MapNiche
+
+impl<T, W, N> ArchiveWith<Option<T>> for MapNiche<W, N>
+where
+    W: ArchiveWith<T> + ?Sized,
+    N: Niching<<W as ArchiveWith<T>>::Archived> + ?Sized,
+{
+    type Archived = NichedOption<<W as ArchiveWith<T>>::Archived, N>;
+    type Resolver = Option<<W as ArchiveWith<T>>::Resolver>;
+
+    fn resolve_with(
+        field: &Option<T>,
+        resolver: Self::Resolver,
+        out: Place<Self::Archived>,
+    ) {
+        let out = NichedOption::munge_place(out);
+        match field {
+            Some(value) => {
+                let resolver = resolver.expect("non-niched resolver");
+                W::resolve_with(value, resolver, out);
+            }
+            None => N::resolve_niched(out),
+        }
+    }
+}
+
+impl<T, W, N, S> SerializeWith<Option<T>, S> for MapNiche<W, N>
+where
+    W: SerializeWith<T, S> + ?Sized,
+    N: Niching<<W as ArchiveWith<T>>::Archived> + ?Sized,
+    S: Fallible + ?Sized,
+{
+    fn serialize_with(
+        field: &Option<T>,
+        serializer: &mut S,
+    ) -> Result<Self::Resolver, S::Error> {
+        match field {
+            Some(value) => W::serialize_with(value, serializer).map(Some),
+            None => Ok(None),
+        }
+    }
+}
+
+impl<T, W, N, D>
+    DeserializeWith<
+        NichedOption<<W as ArchiveWith<T>>::Archived, N>,
+        Option<T>,
+        D,
+    > for MapNiche<W, N>
+where
+    W: ArchiveWith<T> + DeserializeWith<<W as ArchiveWith<T>>::Archived, T, D>,
+    N: Niching<<W as ArchiveWith<T>>::Archived> + ?Sized,
+    D: Fallible + ?Sized,
+{
+    fn deserialize_with(
+        field: &NichedOption<<W as ArchiveWith<T>>::Archived, N>,
+        deserializer: &mut D,
+    ) -> Result<Option<T>, D::Error> {
+        field
+            .as_ref()
+            .map(|value| W::deserialize_with(value, deserializer))
+            .transpose()
+    }
+}
+
+// DefaultNiche
+
+impl<T> ArchiveWith<Option<T>> for DefaultNiche
+where
+    T: Archive,
+    Self: Niching<T::Archived>,
+{
+    type Archived = NichedOption<T::Archived, Self>;
+    type Resolver = Option<T::Resolver>;
+
+    fn resolve_with(
+        field: &Option<T>,
+        resolver: Self::Resolver,
+        out: Place<Self::Archived>,
+    ) {
+        NicheInto::<Self>::resolve_with(field, resolver, out);
+    }
+}
+
+impl<T, S> SerializeWith<Option<T>, S> for DefaultNiche
+where
+    T: Serialize<S>,
+    Self: Niching<T::Archived>,
+    S: Fallible + ?Sized,
+{
+    fn serialize_with(
+        field: &Option<T>,
+        serializer: &mut S,
+    ) -> Result<Self::Resolver, S::Error> {
+        NicheInto::<Self>::serialize_with(field, serializer)
+    }
+}
+
+impl<T, D> DeserializeWith<NichedOption<T::Archived, Self>, Option<T>, D>
+    for DefaultNiche
+where
+    T: Archive<Archived: Deserialize<T, D>>,
+    Self: Niching<T::Archived>,
+    D: Fallible + ?Sized,
+{
+    fn deserialize_with(
+        field: &NichedOption<T::Archived, Self>,
+        deserializer: &mut D,
+    ) -> Result<Option<T>, D::Error> {
+        NicheInto::<Self>::deserialize_with(field, deserializer)
+    }
+}
+
 // Inline
 
 impl<F: Archive> ArchiveWith<&F> for Inline {
@@ -553,13 +806,16 @@ where
 
 #[cfg(test)]
 mod tests {
+    use core::f32;
+
     use crate::{
         api::test::{deserialize, roundtrip, roundtrip_with, to_archived},
+        niche::niching::{NaN, Zero},
         rancor::Fallible,
         ser::Writer,
         with::{
-            ArchiveWith, AsBox, DeserializeWith, Identity, Inline, InlineAsBox,
-            Niche, SerializeWith, Unsafe, With,
+            ArchiveWith, AsBox, AsString, AsVec, DeserializeWith, Identity,
+            Inline, InlineAsBox, Niche, NicheInto, SerializeWith, Unsafe, With,
         },
         Archive, Archived, Deserialize, Place, Serialize,
     };
@@ -729,6 +985,38 @@ mod tests {
         });
     }
 
+    #[test]
+    fn with_str() {
+        #[derive(Archive, Serialize, Deserialize)]
+        #[rkyv(crate)]
+        struct Test<'a> {
+            #[rkyv(with = AsString)]
+            value: &'a str,
+        }
+
+        let a = "hello world";
+        let value = Test { value: a };
+        to_archived(&value, |archived| {
+            assert_eq!(archived.value.as_str(), "hello world");
+        });
+    }
+
+    #[test]
+    fn with_slice() {
+        #[derive(Archive, Serialize, Deserialize)]
+        #[rkyv(crate)]
+        struct Test<'a> {
+            #[rkyv(with = AsVec)]
+            value: &'a [bool],
+        }
+
+        let a: &[bool] = &[true, true, false, true];
+        let value = Test { value: a };
+        to_archived(&value, |archived| {
+            assert_eq!(archived.value.as_slice(), &[true, true, false, true]);
+        });
+    }
+
     #[test]
     fn with_niche_nonzero() {
         use core::{
@@ -741,7 +1029,7 @@ mod tests {
 
         #[derive(Archive, Serialize, Deserialize)]
         #[rkyv(crate)]
-        struct Test {
+        struct TestNiche {
             #[rkyv(with = Niche)]
             a: Option<NonZeroI8>,
             #[rkyv(with = Niche)]
@@ -756,6 +1044,23 @@ mod tests {
             f: Option<NonZeroUsize>,
         }
 
+        #[derive(Archive, Serialize, Deserialize)]
+        #[rkyv(crate)]
+        struct TestZeroNiche {
+            #[rkyv(with = NicheInto<Zero>)]
+            a: Option<NonZeroI8>,
+            #[rkyv(with = NicheInto<Zero>)]
+            b: Option<NonZeroI32>,
+            #[rkyv(with = NicheInto<Zero>)]
+            c: Option<NonZeroIsize>,
+            #[rkyv(with = NicheInto<Zero>)]
+            d: Option<NonZeroU8>,
+            #[rkyv(with = NicheInto<Zero>)]
+            e: Option<NonZeroU32>,
+            #[rkyv(with = NicheInto<Zero>)]
+            f: Option<NonZeroUsize>,
+        }
+
         #[derive(Archive, Serialize, Deserialize)]
         #[rkyv(crate)]
         struct TestNoNiching {
@@ -767,7 +1072,7 @@ mod tests {
             f: Option<NonZeroUsize>,
         }
 
-        let value = Test {
+        let value = TestNiche {
             a: Some(NonZeroI8::new(10).unwrap()),
             b: Some(NonZeroI32::new(10).unwrap()),
             c: Some(NonZeroIsize::new(10).unwrap()),
@@ -790,7 +1095,7 @@ mod tests {
             assert_eq!(archived.f.as_ref().unwrap().get(), 10);
         });
 
-        let value = Test {
+        let value = TestNiche {
             a: None,
             b: None,
             c: None,
@@ -807,6 +1112,101 @@ mod tests {
             assert!(archived.f.is_none());
         });
 
+        assert!(
+            size_of::<Archived<TestNiche>>()
+                < size_of::<Archived<TestNoNiching>>()
+        );
+
+        let value = TestZeroNiche {
+            a: Some(NonZeroI8::new(10).unwrap()),
+            b: Some(NonZeroI32::new(10).unwrap()),
+            c: Some(NonZeroIsize::new(10).unwrap()),
+            d: Some(NonZeroU8::new(10).unwrap()),
+            e: Some(NonZeroU32::new(10).unwrap()),
+            f: Some(NonZeroUsize::new(10).unwrap()),
+        };
+        to_archived(&value, |archived| {
+            assert!(archived.a.is_some());
+            assert_eq!(archived.a.as_ref().unwrap().get(), 10);
+            assert!(archived.b.is_some());
+            assert_eq!(archived.b.as_ref().unwrap().get(), 10);
+            assert!(archived.c.is_some());
+            assert_eq!(archived.c.as_ref().unwrap().get(), 10);
+            assert!(archived.d.is_some());
+            assert_eq!(archived.d.as_ref().unwrap().get(), 10);
+            assert!(archived.e.is_some());
+            assert_eq!(archived.e.as_ref().unwrap().get(), 10);
+            assert!(archived.f.is_some());
+            assert_eq!(archived.f.as_ref().unwrap().get(), 10);
+        });
+
+        let value = TestZeroNiche {
+            a: None,
+            b: None,
+            c: None,
+            d: None,
+            e: None,
+            f: None,
+        };
+        to_archived(&value, |archived| {
+            assert!(archived.a.is_none());
+            assert!(archived.b.is_none());
+            assert!(archived.c.is_none());
+            assert!(archived.d.is_none());
+            assert!(archived.e.is_none());
+            assert!(archived.f.is_none());
+        });
+
+        assert!(
+            size_of::<Archived<TestZeroNiche>>()
+                < size_of::<Archived<TestNoNiching>>()
+        );
+    }
+
+    #[test]
+    fn with_niche_float_nan() {
+        #[derive(Archive, Serialize, Deserialize)]
+        #[rkyv(crate)]
+        struct Test {
+            #[rkyv(with = NicheInto<NaN>)]
+            a: Option<f32>,
+            #[rkyv(with = NicheInto<NaN>)]
+            b: Option<f64>,
+        }
+
+        #[derive(Archive, Serialize, Deserialize)]
+        #[rkyv(crate)]
+        struct TestNoNiching {
+            a: Option<f32>,
+            b: Option<f64>,
+        }
+
+        let value = Test {
+            a: Some(123.45),
+            b: Some(123.45),
+        };
+        to_archived(&value, |archived| {
+            assert!(archived.a.is_some());
+            assert_eq!(archived.a.as_ref().unwrap().to_native(), 123.45);
+            assert!(archived.b.is_some());
+            assert_eq!(archived.b.as_ref().unwrap().to_native(), 123.45);
+        });
+
+        let value = Test {
+            a: Some(f32::NAN),
+            b: Some(f64::NAN),
+        };
+        to_archived(&value, |archived| {
+            assert!(archived.a.is_none());
+            assert!(archived.b.is_none());
+        });
+
+        let value = Test { a: None, b: None };
+        to_archived(&value, |archived| {
+            assert!(archived.a.is_none());
+            assert!(archived.b.is_none());
+        });
+
         assert!(
             size_of::<Archived<Test>>() < size_of::<Archived<TestNoNiching>>()
         );
