@@ -339,7 +339,7 @@ where
         let should_write = match style {
             SpanMode::Open { .. } | SpanMode::Event => true,
             // Print the parent of a new span again before entering the child
-            SpanMode::PreOpen { .. } if self.config.verbose_entry => true,
+            SpanMode::PreOpen if self.config.verbose_entry => true,
             SpanMode::Close { verbose } => verbose,
             // Generated if `span_retrace` is enabled
             SpanMode::Retrace { .. } => true,
@@ -601,6 +601,18 @@ where
             }
         }
     }
+
+    fn on_record(&self, id: &Id, values: &tracing_core::span::Record<'_>, ctx: Context<S>) {
+        let Some(_guard) = Self::is_recursive() else {
+            return;
+        };
+
+        if let Some(span) = ctx.span(id) {
+            if let Some(data) = span.extensions_mut().get_mut::<Data>() {
+                values.record(data);
+            }
+        }
+    }
 }
 
 fn scope_path<'a, R: LookupSpan<'a>>(span: &SpanRef<'a, R>) -> ScopeFromRoot<'a, R> {
