@@ -21,7 +21,7 @@ fn ms(duration: Duration, round: Round) -> u64 {
 
     // Round up.
     let millis = match round {
-        Round::Up => (duration.subsec_nanos() + NANOS_PER_MILLI - 1) / NANOS_PER_MILLI,
+        Round::Up => duration.subsec_nanos().div_ceil(NANOS_PER_MILLI),
         Round::Down => duration.subsec_millis(),
     };
 
